This program implements a wallet that holds bitcoins. Bitcoin is a type based on float64. Wallet is a
type that allows to deposit and withdraw money and get the wallet's balance.
Also in main.go there is a function with an interactive menu where you can see the implementation of this wallet.